
var lsKeyData = "data";
var lsKeySelection = "sel";

var newItemValue = "(new)";
var newItemTitle = "Nuevo QR";

var data = {};
// When starting, load the data from local storage.
// Data is saved as JSON
var dataStr = localStorage.getItem(lsKeyData);
if(dataStr) data = JSON.parse(dataStr);

// The last selected item
var selection = localStorage.getItem(lsKeyData)

// All elements that have an id will be in elem
var elem = {};

// Collect all elements that have an id
// and put them into obj.
function elements(obj) {
  var list = document.getElementsByTagName("*");
  for(var i=0; i<list.length; ++i) {
    var e = list.item(i);
    if(e.id) obj[e.id] = e;
  }
}

function saveData() {
  localStorage.setItem(lsKeyData,JSON.stringify(data));
}


// Show the QR code for given text
function showCode(text) {
  elem.qrcode.innerHTML = "";
  var size = document.body.clientWidth*0.8;
  var qrcode = new QRCode("qrcode", {
    text: text,
    width: size,
    height: size,
    colorDark : "#000000",
    colorLight : "#ffffff",
    correctLevel : QRCode.CorrectLevel.H
  });
}

function populateSelector() {
  elem.selector.innerHTML = "";
  var newOpt = document.createElement("option");
  newOpt.value = newItemValue;
  newOpt.innerText = newItemTitle;
  elem.selector.appendChild(newOpt);
  var keys = [];
  for(var key in data) {if(data.hasOwnProperty(key)) keys.push(key);}
  keys.sort();
  for(var i=0; i<keys.length; ++i) {
    var key = keys[i];
    var opt = document.createElement("option");
    opt.innerText = key;
    opt.value = key;
    elem.selector.appendChild(opt);
  }
  if(selection && data[selection]) elem.selector.value = selection;
  else
  if(!elem.selector.value || !data[elem.selector.value]) elem.selector.value = newItemValue;
}

// Switch to the editor div
function switchToEdit() {
  elem.showItem.style.display = "none";
  elem.editItem.style.display = "inline-block";
  var item = elem.selector.value;
  if(item==newItemValue) {
    elem.editLabel.value = "";
    elem.editText.value = "";
  }
  else {
    elem.editLabel.value = item;
    elem.editText.value = data[item];
  }
  updateButtons();
}

// Switch to the show div
function switchToShow() {
  if(elem.selector.value==newItemValue) { switchToEdit(); return; }
  elem.editItem.style.display = "none";
  elem.showItem.style.display = "inline-block";
  var item = elem.selector.value;
  if(item==newItemValue) {
    elem.itemText.innerText = "";
    elem.qrcode.innerHTML = "";
  }
  else {
    var text = data[item];
    elem.itemText.innerText = text;
    showCode(text);
  }
}

// Switch to the selected item
function itemSelected() {
  var item = elem.selector.value;
  if(item==newItemValue) switchToEdit();
  else switchToShow();
}

// Save selection and switch to the selected item
function selectorChanged() {
  localStorage.setItem(lsKeySelection,elem.selector.value);
  itemSelected();
}

// Save new or modified item
function saveItem() {
  var item = elem.editLabel.value;
  var text = elem.editText.value;
  if(item==""||text=="") return;
  data[item] = text;
  var oldItem = elem.selector.value;
  if(item!=oldItem && oldItem!=newItemValue) delete data[oldItem];
  saveData();
  populateSelector();
  elem.selector.value = item;
  selectorChanged();
}


// Cancel button
function cancelItem() {
  switchToEdit();
}

// Delete button
function deleteItem() {
  var item = elem.selector.value;
  delete data[item];
  saveData();
  populateSelector();
  itemSelected();
}



function menuItemClicked(id) {
  if(id=="edit") {
    switchToEdit();
  }
}

function onLoad() {
  elements(elem);
  populateSelector();
  itemSelected();
  document.addEventListener('optionsMenuItemClicked', function(e) {
    menuItemClicked(e.detail.id);
  });
}
